Welcome to {{ cookiecutter.project_name }}'s documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   ../README.md
   installation
   usage
   authors
   ../HISTORY.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
